@@ -10,22 +10,20 @@ This module implements the Audyssey settings of Denon AVR receivers.
 import logging
 from io import BytesIO
 import xml.etree.ElementTree as ET
-from requests.exceptions import RequestException
+from requests.exceptions import RequestException, ConnectTimeout
 
 _LOGGER = logging.getLogger("Audyssey")
 
 MULTI_EQ_MAP = {"0": "Off", "1": "Flat", "2": "L/R Bypass", "3": "Reference"}
-MULTI_EQ_MAP_LABELS = dict((value, key) for key, value in MULTI_EQ_MAP.items())
+MULTI_EQ_MAP_LABELS = {(value, key) for key, value in MULTI_EQ_MAP.items()}
 
 REF_LVL_OFFSET_MAP = {"0": "0dB", "1": "+5dB", "2": "+10dB", "3": "+15dB"}
-REF_LVL_OFFSET_MAP_LABELS = dict(
-    (value, key) for key, value in REF_LVL_OFFSET_MAP.items()
-)
+REF_LVL_OFFSET_MAP_LABELS = {
+    (value, key) for key, value in REF_LVL_OFFSET_MAP.items()}
 
 DYNAMIC_VOLUME_MAP = {"0": "Off", "1": "Light", "2": "Medium", "3": "Heavy"}
-DYNAMIC_VOLUME_MAP_LABELS = dict(
-    (value, key) for key, value in DYNAMIC_VOLUME_MAP.items()
-)
+DYNAMIC_VOLUME_MAP_LABELS = {
+    (value, key) for key, value in DYNAMIC_VOLUME_MAP.items()}
 
 COMMAND_ENDPOINT = "/goform/AppCommand0300.xml"
 
@@ -57,7 +55,9 @@ class Audyssey:
         xml_tree.write(body, encoding="utf-8", xml_declaration=True)
         try:
             result = self.receiver.send_post_command(
-                command=COMMAND_ENDPOINT, body=body.getvalue())
+                COMMAND_ENDPOINT, body.getvalue())
+        except ConnectTimeout:
+            return
         except RequestException:
             _LOGGER.error(
                 "No connection to %s end point on host %s",
@@ -81,7 +81,7 @@ class Audyssey:
             return
 
     def update(self):
-        """Update settings."""
+        """Get current Audyssey settings."""
         root = ET.Element("tx")
         cmd = ET.SubElement(root, "cmd", id="3")
         ET.SubElement(cmd, "name").text = "GetAudyssey"
@@ -91,7 +91,7 @@ class Audyssey:
             ET.SubElement(param_list, "param", name=param)
         tree = ET.ElementTree(root)
 
-        response = self.send_command(xml_tree=tree)
+        response = self.send_command(tree)
         if response is None:
             return False
 
@@ -123,6 +123,7 @@ class Audyssey:
         return True
 
     def _set_audyssey(self, parameter, value):
+        """Set Audyssey parameter."""
         root = ET.Element("tx")
         cmd = ET.SubElement(root, "cmd", id="3")
         ET.SubElement(cmd, "name").text = "SetAudyssey"
@@ -144,19 +145,18 @@ class Audyssey:
 
     def dynamiceq_off(self):
         """Turn DynamicEQ off."""
-        if self._set_audyssey(parameter="dynamiceq", value=0) is True:
+        if self._set_audyssey("dynamiceq", 0) is True:
             self.dynamiceq = False
 
     def dynamiceq_on(self):
         """Turn DynamicEQ on."""
-        if self._set_audyssey(parameter="dynamiceq", value=1) is True:
+        if self._set_audyssey("dynamiceq", 1) is True:
             self.dynamiceq = True
 
     def set_multieq(self, setting):
         """Set MultiEQ mode."""
         if self._set_audyssey(
-                parameter="multeq", value=MULTI_EQ_MAP_LABELS.get(setting)
-                ) is True:
+                "multeq", MULTI_EQ_MAP_LABELS.get(setting)) is True:
             self.multeq = setting
 
     def set_reflevoffset(self, setting):
@@ -164,15 +164,12 @@ class Audyssey:
         # Reference level offset can only be used with DynamicEQ
         if self.dynamiceq is True:
             if self._set_audyssey(
-                    parameter="reflevoffset",
-                    value=REF_LVL_OFFSET_MAP_LABELS.get(setting)
+                    "reflevoffset", REF_LVL_OFFSET_MAP_LABELS.get(setting)
                         ) is True:
                 self.reflevoffset = setting
 
     def set_dynamicvol(self, setting):
         """Set Dynamic Volume."""
         if self._set_audyssey(
-                parameter="dynamicvol",
-                value=DYNAMIC_VOLUME_MAP_LABELS.get(setting)
-                ) is True:
+                "dynamicvol", DYNAMIC_VOLUME_MAP_LABELS.get(setting)) is True:
             self.dynamicvol = setting
